@@ -1,27 +1,23 @@
 #' @title A directed graph
-#' 
 #' @description An R6 class representing a digraph (a directed graph).
-#' 
-#' @details Encapsulates and provides methods for computation and checking of 
-#' directed graphs (digraphs). Inherits from class \code{Graph}. 
-#'
-#' @references{ 
+#' @details Encapsulates and provides methods for computation and checking of
+#' directed graphs (digraphs). Inherits from class \code{Graph}.
+#' @references{
 #'   Gansner ER, Koutsofios E, North SC, Vo K-P. A technique for drawing
 #'   directed graphs. \emph{IEEE Transactions on Software Engineering},
 #'   1993;\bold{19}:214–30, \doi{10.1109/32.221135}.
-#' 
-#'   Gross JL, Yellen J, Zhang P. Handbook of Graph Theory. Second edition, 
+#'
+#'   Gross JL, Yellen J, Zhang P. Handbook of Graph Theory. Second edition,
 #'   Chapman and Hall/CRC.; 2013, \doi{10.1201/b16132}.
 #'
-#'   Kahn AB, Topological Sorting of Large Networks, 
+#'   Kahn AB, Topological Sorting of Large Networks,
 #'   \emph{Communications of the \acronym{ACM}},
 #'   1962;\strong{5}:558-562, \doi{10.1145/368996.369025}.
 #' }
-#' 
 #' @docType class
 #' @author Andrew Sims \email{andrew.sims@@newcastle.ac.uk}
 #' @export
-#' 
+#'
 Digraph <- R6::R6Class(
   classname = "Digraph",
   lock_class = TRUE,
@@ -32,9 +28,9 @@ Digraph <- R6::R6Class(
     BD = NULL     # incidence matrix for digraph
   ),
   public = list(
-    
-    #' @description 
-    #' Create a new \code{Digraph} object from sets of nodes and edges. 
+
+    #' @description Create a new \code{Digraph} object from sets of nodes and
+    #' edges.
     #' @param V A list of Nodes.
     #' @param A A list of Arrows.
     #' @return A Digraph object.
@@ -42,8 +38,8 @@ Digraph <- R6::R6Class(
       # check and set arrows
       abortifnot(
         is.list(A),
-        message = "A must be a list", 
-        class="non-list_arrows"
+        message = "A must be a list",
+        class = "non-list_arrows"
       )
       abortifnot(
         all(is_Arrow(A)),
@@ -65,39 +61,40 @@ Digraph <- R6::R6Class(
     #' the column vertex, with the convention of self loops being counted once,
     #' unless \code{boolean} is \code{TRUE} when cells are either \code{FALSE}
     #' (not adjacent) or \code{TRUE} (adjacent).
-    #' @param boolean If \code{TRUE}, the adjacency matrix is logical, each 
+    #' @param boolean If \code{TRUE}, the adjacency matrix is logical, each
     #' cell is \code{{FALSE,TRUE}}.
     #' @return A square integer matrix with the number of rows and columns
     #' equal to the order of the graph. The rows and columns are in the
     #' same order as \code{V}. If the nodes have defined and unique labels the
-    #' dimnames of the matrix are the labels of the nodes. 
+    #' dimnames of the matrix are the labels of the nodes.
     digraph_adjacency_matrix = function(boolean = FALSE) {
       # check argument
       abortifnot(is.logical(boolean),
-        message = "Argument 'boolean' must be 'logical'.", 
-        class="non-logical_boolean"
+        message = "Argument 'boolean' must be 'logical'.",
+        class = "non-logical_boolean"
       )
       # create if not saved
       if (is.null(private$AD)) {
         # create matrix
-        L <- vapply(X = private$V, FUN.VALUE = "x", FUN = function(v) v$label())
+        vi <- self$vertex_along()
+        L <- self$vertex_label(vi)
         n <- self$order()
         if (anyDuplicated(L) == 0L && all(nchar(L) > 0L)) {
           A <- matrix(
-            rep(0L, times=n * n), 
-            nrow=n, 
-            dimnames=list(out.node = L, in.node = L)
+            rep(0L, times = n * n),
+            nrow = n,
+            dimnames = list(out.node = L, in.node = L)
           )
         } else {
-          A <- matrix(rep(0L, times=n * n), nrow=n)
+          A <- matrix(rep(0L, times = n * n), nrow = n)
         }
         # populate it
-        for (e in private$E) {
+        for (e in self$edges()) {
           s <- self$vertex_index(e$source())
           t <- self$vertex_index(e$target())
           A[[s, t]] <- A[[s, t]] + 1L
         }
-        # save it 
+        # save it
         private$AD <- A
       } else {
         # read it
@@ -109,11 +106,11 @@ Digraph <- R6::R6Class(
       }
       return(A)
     },
-    
-    #' @description Compute the incidence matrix for the digraph. 
+
+    #' @description Compute the incidence matrix for the digraph.
     #' @details Each row is a vertex and each column is an edge. Edges leaving
     #' a vertex have value -1 and edges entering have value +1. By convention
-    #' self loops have value 0 (1-1). If all vertexes have defined and unique 
+    #' self loops have value 0 (1-1). If all vertexes have defined and unique
     #' labels and all edges have defined and unique labels, the dimnames of the
     #' matrix are the labels of the vertexes and edges.
     #' @return The incidence matrix of integers.
@@ -121,23 +118,23 @@ Digraph <- R6::R6Class(
       # create, if NULL
       if (is.null(private$BD)) {
         # create matrix
-        LV <- vapply(private$V, FUN.VALUE = "x", FUN = function(v) v$label())
-        LE <- vapply(private$E, FUN.VALUE = "x", FUN = function(e) e$label())
+        LV <- self$vertex_label(self$vertex_along())
+        LE <- self$edge_label(self$edge_along())
         nv <- self$order()
         ne <- self$size()
         if (anyDuplicated(LV) == 0L && anyDuplicated(LE) == 0L &&
             all(nchar(LV) > 0L) && all(nchar(LE) > 0L)
         ) {
           B <- matrix(
-            rep(0L, times = nv * ne), 
-            nrow = nv, 
+            rep(0L, times = nv * ne),
+            nrow = nv,
             dimnames = list(vertex = LV, edge = LE)
           )
         } else {
           B <- matrix(rep(0L, times = nv * ne), nrow = nv)
         }
         # populate it
-        for (e in private$E) {
+        for (e in self$edges()) {
           s <- self$vertex_index(e$source())
           t <- self$vertex_index(e$target())
           ei <- self$edge_index(e)
@@ -159,7 +156,7 @@ Digraph <- R6::R6Class(
       # return matrix
       return(B)
     },
-    
+
     #' @description Topologically sort the vertexes in the digraph.
     #' @details Uses Kahn's algorithm (Kahn, 1962).
     #' @return A list of vertexes, topologically sorted. If the digraph has
@@ -173,7 +170,7 @@ Digraph <- R6::R6Class(
       # S is a stack of all vertexes with no incoming edge
       S <- Stack$new()
       for (n in seq_len(ncol(AA))) {
-        if (sum(AA[,n]) == 0L) {
+        if (sum(AA[, n]) == 0L) {
           S$push(n)
         }
       }
@@ -184,9 +181,9 @@ Digraph <- R6::R6Class(
         # add n to tail of L
         L$push(n)
         # for each node m with an edge e from n to m
-        for (m in which(AA[n,] > 0L, arr.ind = TRUE)) {
+        for (m in which(AA[n, ] > 0L)) {
           # remove edge e from graph
-          AA[[n,m]] <- 0L
+          AA[[n, m]] <- 0L
           # if m has no other incoming edges, insert m into S
           if (sum(AA[, m]) == 0L) {
             S$push(m)
@@ -194,21 +191,20 @@ Digraph <- R6::R6Class(
         }
       }
       # return list of nodes indexed by L
-      LL <- lapply(L$as_list(), function(l) private$V[[l]])
+      LL <- lapply(L$as_list(), self$vertex_at)
       return(LL)
     },
 
     #' @description Test whether the graph is connected.
     #' @details For digraphs this will always return \code{FALSE} because
-    #' \dfn{connected} is not defined. Function \code{weakly_connected} 
+    #' \dfn{connected} is not defined. Function \code{weakly_connected}
     #' calculates whether the underlying graph is connected.
     #' @return \code{TRUE} if connected, \code{FALSE} if not.
     is_connected = function() {
       return(FALSE)
     },
 
-    #' @description 
-    #' Test whether the digraph is weakly connected, i.e. if the
+    #' @description Test whether the digraph is weakly connected, i.e. if the
     #' underlying graph is connected.
     #' @return \code{TRUE} if connected, \code{FALSE} if not.
     is_weakly_connected = function() {
@@ -218,22 +214,22 @@ Digraph <- R6::R6Class(
 
     #' @description Checks for the presence of a cycle in the graph.
     #' @details Attempts to do a topological sort. If the sort does not contain
-    #' all vertexes, the digraph contains at least one cycle. This method 
+    #' all vertexes, the digraph contains at least one cycle. This method
     #' overrides \code{is_acyclic} in \code{Graph}.
     #' @return \code{TRUE} if no cycles detected.
     is_acyclic = function() {
       L <- self$topological_sort()
-      return(length(L)==length(private$V))
-    },    
+      return(length(L) == self$order())
+    },
 
     #' @description Is the digraph's underlying graph a tree?
     #' @details It is a tree if it is connected and acyclic.
-    #' @return \code{TRUE} if the underlying graph is a tree; \code{FALSE} 
+    #' @return \code{TRUE} if the underlying graph is a tree; \code{FALSE}
     #' if not.
     is_tree = function() {
       return(self$is_weakly_connected() && super$is_acyclic())
     },
-    
+
     #' @description Is the digraph's underlying graph a polytree?
     #' @details It is a polytree if it is directed, connected and acyclic.
     #' Because the object is a digraph (directed), this is synonymous with
@@ -252,16 +248,16 @@ Digraph <- R6::R6Class(
     is_arborescence = function() {
       # there must be one and only one root vertex
       B <- self$digraph_incidence_matrix()
-      u <- which(apply(B, MARGIN = 1L, function(r) !any(r > 0L)), arr.ind=TRUE)
+      u <- which(apply(B, MARGIN = 1L, function(r) !any(r > 0L)))
       if (length(u) != 1L) {
         return(FALSE)
       }
       # there must be exactly one path from the root to all other vertexes
       np <- vapply(
-        setdiff(seq_along(private$V), u), 
-        FUN.VAL = 1L, 
+        setdiff(self$vertex_along(), u),
+        FUN.VAL = 1L,
         function(v) {
-          P <- self$paths(private$V[[u]], private$V[[v]])
+          P <- self$paths(self$vertex_at(u), self$vertex_at(v))
           return(length(P))
         }
       )
@@ -272,58 +268,106 @@ Digraph <- R6::R6Class(
       return(TRUE)
     },
 
-    #' @description Find the direct successors of a node. 
-    #' @param v The index vertex.
-    #' @return A list of nodes or an empty list if the specified
+    #' @description Find the direct successors of a node.
+    #' @param v The index vertex (a scalar; does not accept a vector of nodes).
+    #' @return A list of Nodes or an empty list if the specified
     #' node has no successors.
     direct_successors = function(v) {
       iv <- self$vertex_index(v)
-      abortifnot(
-        !is.na(iv),
-        message = "Argument 'v' is not in graph", 
-        class = "not_in_graph"
+      abortif(
+        is.list(v),
+        is.na(iv),
+        message = "Argument 'v' is not in graph, or is not a single node",
+        class = "invalid_argument"
       )
       AA <- self$digraph_adjacency_matrix()
-      iw <- which(AA[iv, ] >= 1L, arr.ind = TRUE)
-      successors <- private$V[iw]
+      iw <- which(AA[iv, ] >= 1L)
+      successors <- self$vertex_at(iw, as_list = TRUE)
       return(successors)
     },
-      
-    #' @description Find the direct predecessors of a node. 
-    #' @param v The index vertex.
-    #' @return A list of nodes or an empty list if the specified
+
+    #' @description Find the direct predecessors of a node.
+    #' @param v The index vertex (a scalar; does not accept an index of nodes).
+    #' @return A list of Nodes or an empty list if the specified
     #' node has no predecessors.
     direct_predecessors = function(v) {
       iv <- self$vertex_index(v)
-      abortifnot(
-        !is.na(iv),
-        message = "Argument 'v' is not in graph", 
-        class = "not_in_graph"
+      abortif(
+        is.list(v),
+        is.na(iv),
+        message = "Argument 'v' is not in graph or is not a single node",
+        class = "invalid_argument"
       )
       AA <- self$digraph_adjacency_matrix()
-      iw <- which(AA[, iv] >= 1L, arr.ind = TRUE)
-      pred <- private$V[iw]
+      iw <- which(AA[, iv] >= 1L)
+      pred <- self$vertex_at(iw, as_list = TRUE)
       return(pred)
     },
 
+    #' @description Find the node that is the source of the given arrow.
+    #' @details The source node is a property of the arrow, not the digraph of
+    #' which it is part, hence the canonical method for establishing the source
+    #' node of an arrow is via method \code{$source} of an \code{Arrow} object.
+    #' This function is provided for convenience when iterating the arrows of a
+    #' digraph. It raises an error if the arrow is not in the graph. It
+    #' returns the index of the source node, which is a property of the graph;
+    #' the node object itself may be retrieved using the \code{$vertex_at}
+    #' method of the graph.
+    #' @param a An arrow (directed edge), which must be in the digraph.
+    #' @return Index of the source node of the specified edge.
+    arrow_source = function(a) {
+      # check if a is an arrow and is in the graph
+      abortifnot(
+        self$has_edge(a),
+        message = "Argument 'a' is not an Arrow in the graph",
+        class = "not_in_graph"
+      )
+      # find the index of the source node
+      sn <- self$vertex_index(a$source())
+      return(sn)
+    },
+
+    #' @description Find the node that is the target of the given arrow.
+    #' @details The target node is a property of the arrow, not the digraph of
+    #' which it is part, hence the canonical method for establishing the target
+    #' node of an arrow is via method \code{$target} of an \code{$Arrow} object.
+    #' This function is provided for convenience when iterating the arrows of a
+    #' digraph. It raises an error if the arrow is not in the graph. It
+    #' returns the index of the target node, which is a property of the graph;
+    #' the node itself may be retrieved using the \code{$vertex_at} method
+    #' of the graph.
+    #' @param a An arrow (directed edge), which must be in the digraph.
+    #' @return Index of the target node of the specified edge.
+    arrow_target = function(a) {
+      # check arguments
+      abortifnot(
+        self$has_edge(a),
+        message = "Argument 'a' is not an Arrow in the graph",
+        class = "not_in_graph"
+      )
+      # find the target node or its index (checks if a$target is in the graph)
+      tn <- self$vertex_index(a$target())
+      return(tn)
+    },
+
     #' @description Find all directed simple paths from source to target.
-    #' @details In simple paths all vertexes are unique. Uses a recursive 
+    #' @details In simple paths all vertexes are unique. Uses a recursive
     #' depth-first search algorithm.
     #' @param s Source node.
     #' @param t Target node.
-    #' @return A list of ordered node lists. 
-    paths = function(s,t) {
+    #' @return A list of ordered node lists.
+    paths = function(s, t) {
       # check arguments
       is <- self$vertex_index(s)
       if (is.na(is)) {
-        rlang::abort("Argument 's' is not in graph", class="not_in_graph")
+        rlang::abort("Argument 's' is not in graph", class = "not_in_graph")
       }
       it <- self$vertex_index(t)
       if (is.na(it)) {
-        rlang::abort("Argument 't' is not in graph", class="not_in_graph")
+        rlang::abort("Argument 't' is not in graph", class = "not_in_graph")
       }
       # AA is the adjacency matrix
-      AA <- self$digraph_adjacency_matrix(boolean=TRUE)
+      AA <- self$digraph_adjacency_matrix(boolean = TRUE)
       # P is current path
       P <- Stack$new()
       # PLS is list of paths, held as a stack for convenience
@@ -333,10 +377,10 @@ Digraph <- R6::R6Class(
       # recursive DFS, avoiding global variables by using Stacks
       dfs <- function(v) {
         P$push(v)
-        if (v==it) {
+        if (v == it) {
           PLS$push(P$as_list())
         } else {
-          for (w in which(AA[v,],arr.ind=TRUE)) {
+          for (w in which(AA[v, ])) {
             # process any successors not already in the path
             if (!(w %in% P$as_list())) {
               dfs(w)
@@ -348,11 +392,11 @@ Digraph <- R6::R6Class(
       dfs(is)
       # convert vertex indices into vertices before returning
       VPL <- lapply(PLS$as_list(), function(p) {
-        vp <- lapply(p, function(v) private$V[[v]])
+        vp <- lapply(p, self$vertex_at)
       })
       return(VPL)
     },
-    
+
     #' @description Sequence of edges which join the specified path.
     #' @param P A list of Nodes
     #' @param what One of "edge" or "index".
@@ -365,8 +409,15 @@ Digraph <- R6::R6Class(
         message = "'what' must be one of 'edge' or 'index'",
         class = "invalid_argument"
       )
+      # a path must be a list with at least two vertexes
+      abortifnot(
+        is.list(P),
+        length(P) >= 2L,
+        message = "'P' must be a list of at least two nodes",
+        class = "invalid_argument"
+      )
       # check vertexes and get index of each
-      p <- vapply(X = P, FUN.VALUE = 1L, FUN = function(n) self$vertex_index(n))
+      p <- vapply(X = P, FUN.VALUE = 1L, FUN = self$vertex_index)
       # check all the vertices are in the graph
       abortif(
         anyNA(p),
@@ -383,7 +434,7 @@ Digraph <- R6::R6Class(
         B <- self$digraph_incidence_matrix()
         W <- apply(pairs, MARGIN = 1L, function(r) {
           # look for edges leaving s and entering t
-          e <- which((B[r[1L], ] == -1L) & (B[r[2L], ] == 1L), arr.ind = TRUE)
+          e <- which((B[r[[1L]], ] == -1L) & (B[r[[2L]], ] == 1L))
           abortifnot(
             length(e) >= 1L,
             message = "There must be an edge between adjacent nodes in 'P'",
@@ -394,56 +445,75 @@ Digraph <- R6::R6Class(
       }
       # convert edge indices into edges, if required
       if (what == "edge") {
-        W <- lapply(W, function(ie) self$edge_at(ie))
+        W <- lapply(X = W, FUN = self$edge_at)
       }
-      # return the walk 
+      # return the walk
       return(W)
     },
-    
+
     #' @description Exports the digraph in DOT notation.
-    #' @details Writes a representation of the digraph in the 
-    #' \code{graphviz} DOT language 
-    #' (\url{http://graphviz.org/doc/info/lang.html}) for drawing with one
-    #' of the \code{graphviz} tools, including \code{dot} (Gansner, 1993). 
+    #' @details Writes a representation of the digraph in the
+    #' \code{graphviz} DOT language
+    #' (\url{https://graphviz.org/doc/info/lang.html}) for drawing with one
+    #' of the \code{graphviz} tools, including \code{dot} (Gansner, 1993). If
+    #' all nodes have labels, these are used in the graph, otherwise the labels
+    #' are the node indices.
+    #' @param rankdir One of "LR" (default), "TB", "RL" or "BT".
+    #' @param width of the drawing, in inches
+    #' @param height of the drawing, in inches
     #' @return A character vector. Intended for passing to \code{writeLines}
     #' for saving as a text file.
-    as_DOT = function() {
+    as_DOT = function(rankdir = "LR", width = 7.0, height = 7.0) {
       # check whether all nodes have labels
-      nodelab <- all(
-        vapply(
-          private$V, 
-          FUN.VALUE = TRUE, 
-          FUN = function(v) nchar(v$label()) > 0L
-        )
+      vi <- self$vertex_along()
+      nl <- self$vertex_label(vi)
+      nodelab <- all(nchar(x = nl) > 0L)
+      # check rankdir argument
+      abortifnot(
+        rankdir %in% c("LR", "TB", "RL", "BT"),
+        message = "'rankdir' must be one of 'LR', 'TB', 'RL', 'BT'",
+        class = "invalid_rankdir"
+      )
+      # check width and height
+      abortifnot(
+        is.numeric(width), width > 0.0, is.numeric(height), height > 0.0,
+        message = "'width' and 'height' must be numeric and > 0",
+        class = "invalid_size"
       )
       # create stream vector (header+edges+footer)
       indent <- "  "
       o <- vector(mode = "character", length = 0L)
       # write header
       o[[length(o) + 1L]] <- "digraph rdecision {"
-      o[[length(o) + 1L]] <- paste0(indent, 'size="7,7" ;')
-      o[[length(o) + 1L]] <- paste0(indent, "rankdir=LR ;")
+      # write graph attributes
+      o[[length(o) + 1L]] <- paste0(
+        indent,
+        "graph [ ",
+        'rankdir = "', rankdir, '"', ", ",
+        'size = "', width, ",", height, '"',
+        " ] ;"
+      )
       # write edges
-      for (e in private$E) {
+      for (e in self$edges()) {
         s <- e$source()
         t <- e$target()
         o[[length(o) + 1L]] <- paste(
           indent,
-          ifelse(nodelab, paste0('"',s$label(),'"'), self$vertex_index(s)),
+          ifelse(nodelab, paste0('"', s$label(), '"'), self$vertex_index(s)),
           "->",
-          ifelse(nodelab, paste0('"',t$label(),'"'), self$vertex_index(t)),
+          ifelse(nodelab, paste0('"', t$label(), '"'), self$vertex_index(t)),
           ifelse(
-            nchar(e$label()) > 0L, 
+            nchar(e$label()) > 0L,
             paste("[", "label = ", paste0('"', e$label(), '"'), "]"),
             ""
-          ), 
-          ";" 
-        )  
+          ),
+          ";"
+        )
       }
       # footer
       o[[length(o) + 1L]] <- "}"
       # return the stream
       return(o)
     }
-  ) 
+  )
 )
