@@ -16,20 +16,71 @@ gbp <- function(x, p = FALSE) {
   return(s)
 }
 
+## -----------------------------------------------------------------------------
+#' @title Create a placeholder image in a png file
+#' @description Draws a rectangle with a diagonal using the grid package.
+#' @param pngfile name of png file to create.
+#' @param width width of image in pixels
+#' @param height height of image in pixels
+#' @return Name of the png file written to.
+#' @noRd
+placeholder <- function(pngfile = tempfile(fileext = ".png"), width = 480L,
+                        height = 320L) {
+  grDevices::png(pngfile, width = width, height = height)
+  grid::grid.newpage()
+  grid::grid.move.to(
+    x = grid::unit(0.0, "npc"),
+    y = grid::unit(0.0, "npc")
+  )
+  grid::grid.line.to(
+    x = grid::unit(1.0, "npc"),
+    y = grid::unit(1.0, "npc")
+  )
+  grid::grid.move.to(
+    x = grid::unit(0.0, "npc"),
+    y = grid::unit(1.0, "npc")
+  )
+  grid::grid.line.to(
+    x = grid::unit(1.0, "npc"),
+    y = grid::unit(0.0, "npc")
+  )
+  invisible(grDevices::dev.off())
+  return(pngfile)
+}
+
+#' @title Render a DOT format graph as a png file.
+#' @description Uses the \code{dot} command line tool from the graphviz project,
+#' if it is available on the host system, or creates a placeholder image if not.
+#' @param dot GraphViz dot representation in character vector form.
+#' @param pngfile path of png file to create.
+#' @return pathname of the png file created (including extension).
+#' @noRd
+gv2png <- function(dot, pngfile = tempfile(fileext = ".png")) {
+  cmddot <- Sys.which("dot")
+  if (nchar(cmddot["dot"]) > 0L) {
+    dotfile <- tempfile(fileext = ".gv")
+    writeLines(dot, con = dotfile)
+    system2(command = cmddot["dot"], args = c("-Tpng", "-o", pngfile, dotfile))
+  } else {
+    pngfile <- placeholder(pngfile = pngfile)
+  }
+  return(pngfile)
+}
+
 ## -----------------------------------------------------------------------------
 library(rdecision)
 
 ## -----------------------------------------------------------------------------
 states <- c(
-  "A" = "TKR operation for knee problems",
-  "B" = "TKR with serious complications",
-  "C" = "TKR with minor complications",
-  "D" = "Normal health after primary TKR",
-  "E" = "Complex revision",
-  "F" = "Simple revision",
-  "G" = "Other treatments",
-  "H" = "Normal health after TKR revision",
-  "I" = "Death"
+  A = "TKR operation for knee problems",
+  B = "TKR with serious complications",
+  C = "TKR with minor complications",
+  D = "Normal health after primary TKR",
+  E = "Complex revision",
+  F = "Simple revision",
+  G = "Other treatments",
+  H = "Normal health after TKR revision",
+  I = "Death"
 )
 
 ## -----------------------------------------------------------------------------
@@ -144,57 +195,6 @@ SMM_CAS <- SemiMarkovModel$new(
   discount.utility = 0.035
 )
 
-## -----------------------------------------------------------------------------
-#' @title Create a placeholder image in a png file
-#' @description Draws a rectangle with a diagonal using the grid package.
-#' @param pngfile name of png file to create.
-#' @param width width of image in pixels
-#' @param height height of image in pixels
-#' @return Name of the png file written to.
-#' @noRd
-placeholder <- function(pngfile = tempfile(fileext = ".png"), width = 480L,
-                        height = 320L) {
-  grDevices::png(pngfile, width = width, height = height)
-  grid::grid.newpage()
-  grid::grid.move.to(
-    x = grid::unit(0.0, "npc"),
-    y = grid::unit(0.0, "npc")
-  )
-  grid::grid.line.to(
-    x = grid::unit(1.0, "npc"),
-    y = grid::unit(1.0, "npc")
-  )
-  grid::grid.move.to(
-    x = grid::unit(0.0, "npc"),
-    y = grid::unit(1.0, "npc")
-  )
-  grid::grid.line.to(
-    x = grid::unit(1.0, "npc"),
-    y = grid::unit(0.0, "npc")
-  )
-  invisible(grDevices::dev.off())
-  return(pngfile)
-}
-
-#' @title Render a DOT format graph as a png file.
-#' @description Uses the \code{dot} command line tool from the graphviz project,
-#' if it is available on the host system, or creates a placeholder image if not.
-#' @param dot GraphViz dot representation in character vector form.
-#' @param pngfile path of png file to create.
-#' @return pathname of the png file created (including extension).
-#' @noRd
-gv2png <- function(dot, pngfile = tempfile(fileext = ".png")) {
-  cmddot <- Sys.which("dot")
-  if (nchar(cmddot["dot"]) > 0L) {
-    dotfile <- tempfile(fileext = ".gv")
-    writeLines(dot, con = dotfile)
-    system2(command = cmddot["dot"], args = c("-Tpng", "-o", pngfile, dotfile))
-  } else {
-    pngfile <- placeholder(pngfile = pngfile)
-  }
-  return(pngfile)
-}
-
 ## -----------------------------------------------------------------------------
 # images created with dot are more compact than DiagrammeR.
 pngfile <- gv2png(
