@@ -1,5 +1,5 @@
 test_that("incorrect label types are rejected", {
-  expect_silent(n1 <- Node$new("n1"))
+  n1 <- Node$new("n1")
   expect_identical(n1$label(), "n1")
   expect_error(Node$new(42L), class = "non-string_label")
   expect_error(Node$new(TRUE), class = "non-string_label")
